[PATCH 10/57] Staging: bcm: CmHost.c: Renamed variable: "uiSfid" -> "sf_id"

Matthias Beyer mail at beyermatthias.de
Wed Aug 27 11:11:26 UTC 2014


Signed-off-by: Matthias Beyer <mail at beyermatthias.de>
---
 drivers/staging/bcm/CmHost.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/drivers/staging/bcm/CmHost.c b/drivers/staging/bcm/CmHost.c
index 2ba07c2..2a345da 100644
--- a/drivers/staging/bcm/CmHost.c
+++ b/drivers/staging/bcm/CmHost.c
@@ -34,17 +34,17 @@ static void apply_phs_rule_to_all_classifiers(
  *  specified SFID as input parameter.
  *
  * Parameters -	ad: Pointer to the ad structure
  *  uiSfid : Given SFID for matching
  *
  * Returns - Queue index for this SFID(If matched)
  *  Else Invalid Queue Index(If Not matched)
  ************************************************************/
-int SearchSfid(struct bcm_mini_adapter *ad, UINT uiSfid)
+int SearchSfid(struct bcm_mini_adapter *ad, UINT sf_id)
 {
 	int i;
 
 	for (i = (NO_OF_QUEUES-1); i >= 0; i--)
-		if (ad->PackInfo[i].ulSFID == uiSfid)
+		if (ad->PackInfo[i].ulSFID == sf_id)
 			return i;
 
 	return NO_OF_QUEUES+1;
@@ -34,17 +34,17 @@ static void apply_phs_rule_to_all_classifiers(
  *
  * Parameters -	ad: Pointer to the ad structure
- *  uiSfid : Given SFID for matching
+ *  sf_id : Given SFID for matching
  *
  * Returns - Queue index for this SFID(If matched)
-- 
2.1.0



More information about the devel mailing list